library octopus_player;

//dart imports
import 'dart:async';
import 'dart:io';

//flutter imports
import "package:flutter/material.dart";
import 'package:flutter/services.dart';

//other import
import 'package:video_player/video_player.dart';
import './PlayerControls/Controls.dart';
import './PlayerControls/Cycle.dart';

//CREATE THE CLASS THAT DEFINE THE WIDGET STRUCTURE

class OctopusPlayer extends StatefulWidget {
  final String mediaTitle;
  final dynamic mediaSource;
  final double aspectRatio;
  final bool loop;
  final bool autoPlay;

  OctopusPlayer(this.mediaTitle, this.mediaSource,
      {this.aspectRatio = 0.75, this.loop = true, this.autoPlay = true});

  @override
  State<StatefulWidget> createState() {
    return _OctopusPlayerState();
  }
}

class _OctopusPlayerState extends State<OctopusPlayer> {
  VideoPlayerController _videoPlayerController;
  bool _areControlsVisible;
  Timer _timer;

  @protected
  String getTypeOfSource(dynamic source) {
    Uri parseTry = Uri.parse(source);
    if (source is File) {
      return "File";
    } else if (parseTry != null) {
      return "Url";
    } else {
      return "Asset";
    }
  }

  @override
  void initState() {
    super.initState();
    if (getTypeOfSource(widget.mediaSource) == "File") {
      _videoPlayerController = VideoPlayerController.file(widget.mediaSource);
    } else if (getTypeOfSource(widget.mediaSource) == "Url") {
      _videoPlayerController =
          VideoPlayerController.network(widget.mediaSource);
    } else {
      _videoPlayerController = VideoPlayerController.asset(widget.mediaSource);
    }
    _areControlsVisible = true;
    autoHide();
  }

  @override
  void deactivate() {
    super.deactivate();
  }

  @override
  void dispose() {
    _videoPlayerController?.dispose();
    _timer?.cancel();
    SystemChrome.setPreferredOrientations([
      DeviceOrientation.portraitDown,
      DeviceOrientation.portraitUp,
    ]);
    super.dispose();
  }

  void handlerGesture() {
    setState(() {
      _areControlsVisible = !_areControlsVisible;
    });
    autoHide();
  }

  void autoHide() {
    if (_areControlsVisible) {
      _timer = Timer(Duration(seconds: 5),
          () => setState(() => _areControlsVisible = false));
    } else {
      _timer?.cancel();
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.black,
      body: Stack(
        fit: StackFit.expand,
        children: <Widget>[
          Cycle(
            _videoPlayerController,
            (BuildContext context, VideoPlayerController controller) =>
                AspectRatio(
                  aspectRatio: widget.aspectRatio,
                  child: VideoPlayer(_videoPlayerController),
                ),
            widget.loop,
            widget.autoPlay,
          ),
          GestureDetector(
            child: Controls(
              _videoPlayerController,
              visible: _areControlsVisible,
              title: widget.mediaTitle,
            ),
            onTap: handlerGesture,
          ),
        ],
      ),
    );
  }
}
